reset .die on master takeover
authorbodea <bodea>
Fri, 1 Apr 2005 08:54:12 +0000 (08:54 +0000)
committerbodea <bodea>
Fri, 1 Apr 2005 08:54:12 +0000 (08:54 +0000)
Changes
cluster.c
l2tpns.h
l2tpns.spec

diff --git a/Changes b/Changes
index bd597ab..924624a 100644 (file)
--- a/Changes
+++ b/Changes
@@ -1,3 +1,7 @@
+* Fri Apr 1 2005 Brendan O'Dea <bod@optusnet.com.au> 2.0.17
+- Only send RADIUS stop record in sessionshutdown when there's an ip address.
+- Reset .die on master takeover.
+
 * Mon Feb 14 2005 Brendan O'Dea <bod@optusnet.com.au> 2.0.16
 - Ensure that sessionkill is not called on an unopened session (borks
   the freelist).
index 95c64a2..abf5062 100644 (file)
--- a/cluster.c
+++ b/cluster.c
@@ -1,6 +1,6 @@
 // L2TPNS Clustering Stuff
 
-char const *cvs_id_cluster = "$Id: cluster.c,v 1.26.2.3 2005/02/14 05:59:27 bodea Exp $";
+char const *cvs_id_cluster = "$Id: cluster.c,v 1.26.2.4 2005/04/01 08:54:12 bodea Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -579,9 +579,12 @@ void cluster_check_master(void)
                        continue;
                }
 
-                       // Reset all the idle timeouts..
+                       // Reset idle timeouts..
                session[i].last_packet = time_now;
 
+                       // Reset die relative to our uptime rather than the old master's
+               if (session[i].die) session[i].die = TIME;
+
                        // Accumulate un-sent byte counters.
                session[i].cin += sess_local[i].cin;
                session[i].cout += sess_local[i].cout;
index 61aee17..b2d5afb 100644 (file)
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.49.2.4 2005/02/14 05:58:07 bodea Exp $
+// $Id: l2tpns.h,v 1.49.2.5 2005/04/01 08:54:12 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -15,7 +15,7 @@
 #include <sys/types.h>
 #include <libcli.h>
 
-#define VERSION        "2.0.16"
+#define VERSION        "2.0.17"
 
 // Limits
 #define MAXTUNNEL      500             // could be up to 65535
index 20557d8..c38ccd4 100644 (file)
@@ -1,6 +1,6 @@
 Summary: A high-speed clustered L2TP LNS
 Name: l2tpns
-Version: 2.0.16
+Version: 2.0.17
 Release: 1
 Copyright: GPL
 Group: System Environment/Daemons
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 %attr(644,root,root) /usr/share/man/man[58]/*
 
 %changelog
-* Mon Feb 14 2005 Brendan O'Dea <bod@optusnet.com.au> 2.0.16-1
-- 2.0.16 release, see /usr/share/doc/l2tpns-2.0.16/Changes
+* Fri Apr 1 2005 Brendan O'Dea <bod@optusnet.com.au> 2.0.17-1
+- 2.0.17 release, see /usr/share/doc/l2tpns-2.0.17/Changes